# Readme

You can find the full instructions for running this project in [Developer Guige Getting Started](https://developer.dataiku.com/latest/getting-started/quickstart-tutorial/index.html).

The goal of this project is to predict heart attack failures, using the [Heart Failure Prediction Dataset](https://www.kaggle.com/datasets/fedesoriano/heart-failure-prediction). Using python notebooks and Dataiku Machine Learning experiment tracking capabilities, the project will go through data preparation, machine learning experimentation using classic scikit-learn models, and model evaluation. 

## Configuration

### 1. Create a python code environment

To run the notebooks and the different python components of this project, you'll need to create a python>=3.6 [code environment](https://doc.dataiku.com/dss/latest/code-envs/index.html) named `heart-attack-project` with the following required packages:
```
seaborn==0.11.2
mlflow==1.23.1
mlflow[extras]
scikit-learn==0.24.2
protobuf==3.20.*```

[Instructions for creating a new code environment](https://doc.dataiku.com/dss/latest/code-envs/operations-python.html#create-a-code-environment)

### 2. Set the new code environment as default for the project

To make sure the code environment is automatically selected to run all the python scripts in your project, we will change the project settings to use to by default.

- On the top bar, select: `...`>`Settings`>`Code env selection`
- In the **Default Python code env**: 
 - Change *Mode* to `Select an environment`
 - In the *Environment* parameter, select the code environment you've just created
 - Click 'Save' or do a Ctrl+S

## How to run the project

In the following Tutorial, you'll find the guidelines to use the different notebooks to experiment and build your project pipeline.

## Project overview

The project comes with: 
- an [input dataset](dataset:heart_measures)
- three Jupyter Notebooks that we will use to explore that data, experiment and build the project pipeline (the Flow).
- a python repository stored in the [project library](https://doc.dataiku.com/dss/latest/python/reusing-code.html#sharing-python-code-within-a-project), with some python functions that we will be use in the different notebooks

To build the project and create the pipeline, you can run the notebooks one by one in the order described above and follow the instructions described in the notebooks.

### Step 1: Data Preparation

The [first notebook](jupyter_notebook:1 - Prepare the heart_measures dataset for ML modeling) performs a quick data analysis of the input dataset, applies a few data cleaning steps, using some python functions stored in the project library repository, and split the prepared dataset into a train and a test set.

*Hint*: Don't forget to follow the instructions in the **4. Next: use this notebook to create a new step of the pipeline** section of the notebook to create a preparation step on the project pipeline (the Flow). This step is required for the rest of the project.

### Step 2: Machine Learning experimentation

The [second notebook](jupyter_notebook:2 - Experiment different ML approaches) tests different machine learing models and parameters to predict heart failures. It stores all the experiment in our experiment tracking tool.

### Step 3: Deployment and evaluation of the best performing model

The [third notebook](jupyter_notebook:3 - Create a Saved Model using the best performing model) collects the best model optimizing the chosen metric (accuracy) from the experiment tracking tool to deploy it in the project Flow.

*Hint*: Don't forget to follow the instructions in the **5. Next: use this notebook to create a new step on the pipeline** section of the notebook to create a new step on the project pipeline (the Flow) and evaluate the model on the test dataset.
